Crate chroma_forge

Crate chroma_forge 

Chroma Forge

A comprehensive color conversion library for Rust that provides seamless conversion between various color formats including RGB, Hex, HSL, HSV, and CMYK.

Examples

use chroma_forge::Color;

let color = Color::from_hex("#FF5733").unwrap();
println!("RGB: {}", color.to_rgb());
println!("HSL: {}", color.to_hsl());

Structs

Cmyk
CMYK (Cyan, Magenta, Yellow, Key/Black) color representation
Color
Represents a color with various conversion capabilities
Hsl
HSL (Hue, Saturation, Lightness) color representation
Hsv
HSV (Hue, Saturation, Value) color representation
Rgb
RGB color representation

Enums

ColorError
Custom error type for color conversion operations